# $Id: Base.pm 483 2005-08-01 21:39:05Z guillomovitch $
package Youri::Check::Resultset;

=head1 NAME

Youri::Check::Resultset - Abstract resultset

=head1 DESCRIPTION

This abstract class defines Youri::Check::Resultset interface

=cut

use warnings;
use strict;
use Carp;
use Youri::Utils;

=head1 CLASS METHODS

=head2 new(%hash)

Creates and returns a new Youri::Check::Resultset object.

Generic parameters (subclasses may define additional ones):

=over

=item mode output/input

Resultset access mode (default: output).

=back

Warning: do not call directly, call subclass constructor instead.

=cut

sub new {
    my $class   = shift;
    my %options = (
        test     => 0,     # test mode
        verbose  => 0,     # verbose mode
        resolver => undef,  # maintainer resolver, 
        mode     => 'output', # access mode
        @_
    );

    croak "Abstract class" if $class eq __PACKAGE__;

    my $self = bless {
        _test     => $options{test},
        _verbose  => $options{verbose},
        _resolver => $options{resolver},
        _mode     => $options{mode}
    }, $class;

    $self->_init(%options);

    return $self;
}

sub _init {
    # do nothing
}

=head1 INSTANCE METHODS

=head2 add_result($type, $media, $package, $values)

Add given hash reference as a new result for given type and L<Youri::Package::Base> object.

Only possible if resultset has been created in B<input> mode.

=head2 get_maintainers()

Returns the list of all maintainers with results.

=head2 get_iterator($type, $maintainer)

Returns a L<Youri::Check::Resultset::Iterator> object over results for given input type and maintainer (if the last one if defined).

=head1 SUBCLASSING

All instances methods have to be implemented.

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2002-2006, YOURI project

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=cut

1;
